.. _spkg_exceptiongroup:

exceptiongroup: Backport of PEP 654 (exception groups)
======================================================

Description
-----------

Backport of PEP 654 (exception groups)

License
-------

Upstream Contact
----------------

https://pypi.org/project/exceptiongroup/



Type
----

standard


Dependencies
------------

- $(PYTHON)
- :ref:`spkg_pip`

Version Information
-------------------

package-version.txt::

    1.3.0

version_requirements.txt::

    exceptiongroup >=1.2.0

Equivalent System Packages
--------------------------

(none known)
